@@ -11,8 +11,12 @@ are welcome to improve this.
 
 #![deny(missing_docs)]
 
-pub use crate::error::{Error, ErrorKind};
-pub use crate::ffi::{is_jit_available, version};
+extern crate alloc;
+
+pub use crate::{
+    error::{Error, ErrorKind},
+    ffi::{escape, is_jit_available, version},
+};
 
 /**
 PCRE2 regular expressions for matching on arbitrary bytes.
@@ -20,3 +24,4 @@ PCRE2 regular expressions for matching on arbitrary bytes.
 pub mod bytes;
 mod error;
 mod ffi;
+mod pool;
